const { Team, services } = require('pubsweet-component-helper-service')

module.exports = models => async (req, res) => {
  // TO DO: add authsome
  const { collectionId, fragmentId } = req.params
  try {
    const collection = await models.Collection.find(collectionId)
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Fragment ${fragmentId} does not match collection ${collectionId}`,
      })
    const fragment = await models.Fragment.find(fragmentId)
    if (fragment.authors === undefined) {
      return res.status(200).json([])
    }
    const teamHelper = new Team({ TeamModel: models.Team, fragmentId })
    const members = await teamHelper.getTeamMembers({
      role: 'author',
      objectType: 'fragment',
    })

    if (members === undefined)
      return res.status(400).json({
        error: 'The fragment does not have an author Team',
      })

    const membersData = members.map(async member => {
      const user = await models.User.find(member)
      const matchingAuthor = fragment.authors.find(
        author => author.userId === user.id || author.id === user.id,
      )
      return {
        ...user,
        isSubmitting: matchingAuthor.isSubmitting,
        isCorresponding: matchingAuthor.isCorresponding,
      }
    })

    const resBody = await Promise.all(membersData)
    res.status(200).json(resBody)
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
