const logger = require('@pubsweet/logger')

const { services } = require('pubsweet-component-helper-service')

module.exports = models => async (req, res) => {
  // TO DO: add authsome
  const { collectionId, userId, fragmentId } = req.params
  const {
    isSubmitting,
    isCorresponding,
    firstName,
    lastName,
    affiliation,
  } = req.body

  if (!services.checkForUndefinedParams(isSubmitting, isCorresponding)) {
    res.status(400).json({ error: 'Missing parameters' })
    logger.error('some parameters are missing')
    return
  }

  try {
    const collection = await models.Collection.find(collectionId)
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Fragment ${fragmentId} does not match collection ${collectionId}`,
      })
    let fragment = await models.Fragment.find(fragmentId)
    if (fragment.authors === undefined) {
      return res.status(400).json({
        error: 'Collection does not have any authors',
      })
    }
    const user = await models.User.find(userId)
    const matchingAuthor = fragment.authors.find(
      author => author.userId === user.id,
    )
    if (matchingAuthor === undefined) {
      return res.status(400).json({
        error: 'Fragment and user do not match',
      })
    }
    user.firstName = firstName
    user.lastName = lastName
    user.affiliation = affiliation
    await user.save()
    matchingAuthor.isSubmitting = isSubmitting
    matchingAuthor.isCorresponding = isCorresponding
    fragment = await fragment.save()
    return res.status(200).json(fragment)
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
